@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 ###########################################################################
-## File:		functions_alarm.py
+## File:        functions_alarm.py
 ## Description: This file includes the functions needed to set and modify
-##				the alarms
+##                the alarms
 ###########################################################################
 
 from PyQt4 import QtCore, QtGui
@@ -78,16 +78,16 @@ def SetAlarm():
 
 
 
-	
-	
+
+
 
 
 ###########################################################################
 ## Function:    delete_all_preexisting_Alarms
 ## Description: This function searchs for any SleepAnalyser alarms in the
-##				MAEMO alarm queue and deletes them
-##				In case SleepAnalyser crashed during recording, an alarm
-##				might still be in the queue
+##                MAEMO alarm queue and deletes them
+##                In case SleepAnalyser crashed during recording, an alarm
+##                might still be in the queue
 ## Parameters:  none
 ## Returns:     none
 ###########################################################################
@@ -147,8 +147,8 @@ def DeleteAlarm():
 ###########################################################################
 ## Function:    ProcessAlarm
 ## Description: This function checks if the latest value of the blue sleep
-##				alarm curve is over the trigger level and sets off an alarm
-##				or the wake up music
+##                alarm curve is over the trigger level and sets off an alarm
+##                or the wake up music
 ## Parameters:  none
 ## Returns:     none
 ###########################################################################
@@ -199,8 +199,10 @@ def ProcessAlarm():
             CloseMediaPlayer() #close media player
 
     if(data.WakeUp_SongIsActive==True): #when WakeUp music is active, increase volume over time
+#        print records.WakeUp_Song_Volume,  data.CurrentVolume, data.CurrentVolume, float(data.WakeUp_Song_Volume_Increase_Step)/10, data.WakeUp_Song_Volume_Increase_Step
         if(records.WakeUp_Song_Volume>data.CurrentVolume):
-            SetVolume(data.CurrentVolume+1)
+            data.CurrentVolume=data.CurrentVolume+(float(data.WakeUp_Song_Volume_Increase_Step)/10) #increase the volume slowly
+            SetVolume(data.CurrentVolume)
             print "Increase volume to:", data.CurrentVolume
 
 
@@ -210,7 +212,7 @@ def ProcessAlarm():
 ###########################################################################
 ## Function:    ProcessLucid_Dream
 ## Description: This function sets off the lucid dream music if we are
-##				longer than required time in light or deep sleep				
+##                longer than required time in light or deep sleep
 ## Parameters:  none
 ## Returns:     none
 ###########################################################################
