@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 ###########################################################################
-## File:		functions_record.py
+## File:        functions_record.py
 ## Description: This file includes the functions needed to modify and read
-##				the data in the file record.py
+##                the data in the file record.py
 ###########################################################################
 
 import sys
@@ -35,8 +35,8 @@ except:
 ###########################################################################
 ## Function:    ReadAccSensor
 ## Description: Reads the acceleration sensor for x times, where
-##				x=data.Sample_smoothing (normally 10) and averages it
-##				If not on a N900, use randomizer as input
+##                x=data.Sample_smoothing (normally 10) and averages it
+##                If not on a N900, use randomizer as input
 ## Parameters:  none
 ## Returns:     array of accelerations
 ###########################################################################
@@ -66,18 +66,14 @@ def ReadAccSensor():
 ###########################################################################
 ## Function:    GetSensorData
 ## Description: This function initiates the sensor readings.
-##				It gets called once every second from MeasurementTimerLoop()
-##				The from ReadAccSensor returned data gets written into a
-##				temporary buffer. After x times
-##				(where x=data.Value_smoothing, usually 10) it gets averaged
-##				again and finally filled into the records array
+##                It gets called once every second from MeasurementTimerLoop()
+##                The from ReadAccSensor returned data gets written into a
+##                temporary buffer. After x times
+##                (where x=data.Value_smoothing, usually 10) it gets averaged
+##                again and finally filled into the records array
 ## Parameters:  none
 ## Returns:     1 if new data got added to record array, else 0
 ###########################################################################
-
-###########################################################################
-## Get the smoothened sensor data, smoothen it again and fill the data into the main data array
-###########################################################################
 def GetSensorData():
     d=ReadAccSensor()
     data.arrDataTemp[0]=data.arrDataTemp[0]+d[0] #X
@@ -116,7 +112,7 @@ def GetSensorData():
 ###########################################################################
 ## Function:    GetFirstEntry
 ## Description: This function fills in the start time and dummy
-##				acceleration data, so the record array is not empty
+##                acceleration data, so the record array is not empty
 ## Parameters:  none
 ## Returns:     none
 ###########################################################################
@@ -136,12 +132,12 @@ def GetFirstEntry():
 ###########################################################################
 ## Function:    GenerateDerivation
 ## Description: This function processes the recorded data in the record array
-##				The acceleration sensor data (which contains the data of the
-##				relative position of the phone) gets derivated into its derivat.
-##				This shows spices every time the phone changes the relative position
-##				The yellow bars in the graph exactly show this data.
-##				If parameter ProcessAll is False, only the last added data
-##				gets processed. This saves CPU time
+##                The acceleration sensor data (which contains the data of the
+##                relative position of the phone) gets derivated into its derivat.
+##                This shows spices every time the phone changes the relative position
+##                The yellow bars in the graph exactly show this data.
+##                If parameter ProcessAll is False, only the last added data
+##                gets processed. This saves CPU time
 ## Parameters:  ProcessAll: True/False
 ## Returns:     none
 ###########################################################################
@@ -185,14 +181,14 @@ def GenerateDerivation(ProcessAll=False):  #DERIVATION (ABLEITUNG)
 ###########################################################################
 ## Function:    GenerateSleepPattern
 ## Description: This function calculates the sleep pattern out of the movement
-##				data calculated in GenerateDerivation().
-##				It multiplies every derivation value with a defined array,
-##				which is defined in file filterdata.py
-##				As this process is very time consuming, it is exported into
-##				a c function. mylib.py contains the Python function, which
-##				gets converted into a c function by ShedSkin, a Python to C compiler.
-##				If the  c module mylib.so is missing, Python falls back to the
-##				slower Python function.
+##                data calculated in GenerateDerivation().
+##                It multiplies every derivation value with a defined array,
+##                which is defined in file filterdata.py
+##                As this process is very time consuming, it is exported into
+##                a c function. mylib.py contains the Python function, which
+##                gets converted into a c function by ShedSkin, a Python to C compiler.
+##                If the  c module mylib.so is missing, Python falls back to the
+##                slower Python function.
 ## Parameters:  none
 ## Returns:     none
 ###########################################################################
@@ -241,8 +237,8 @@ def DrawGraph(self, QtGui):
         #Draw sleep phase background
         paint.setPen(QtGui.QColor(data.GraphBackground2))
         paint.setBrush(QtGui.QColor(data.GraphBackground2))
-        h1=(data.Ysize-(data.Deep_Sleep_Level*data.Yscale_Movement/40))
-        h2=(data.Ysize-(data.Light_Sleep_Level*data.Yscale_Movement/40))
+        h1=(data.Ysize-(data.Deep_Sleep_Level))
+        h2=(data.Ysize-(data.Light_Sleep_Level))
         paint.drawRect(1, h1-6, records.MaxArrayDataLen-2, h2-h1+2)
 
         #Stop if data is not ok
@@ -347,27 +343,27 @@ def DrawGraph(self, QtGui):
             h=min(peak*data.Yscale_Movement/40, data.Ysize-17) #cut off if higher than graph border
             paint.drawLine(x, data.Ysize-h-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
 
-    #sleep graph (blue graph)
-	pen=QtGui.QPen()
+        #sleep graph (blue graph)
+        pen=QtGui.QPen()
 
-	pen.setColor(QtGui.QColor(19, 54, 255, 150))
-	pen.setWidth(1)
-	paint.setPen(pen)
-	for p in range(0, records.Index-data.Derivation-Xscale, Xscale): #sleep pattern filling
-		i=p-GraphStart_index
-		x=i/Xscale+1
-		y=data.Ysize-records.arrData[6][p+Xscale]-5
-		paint.drawLine(x, data.Ysize-16, x, y)
+        pen.setColor(QtGui.QColor(19, 54, 255, 150))
+        pen.setWidth(1)
+        paint.setPen(pen)
+        for p in range(0, records.Index-data.Derivation-Xscale, Xscale): #sleep pattern filling
+            i=p-GraphStart_index
+            x=i/Xscale+1
+            y=data.Ysize-records.arrData[6][p+Xscale]-5
+            paint.drawLine(x, data.Ysize-16, x, y)
 
-	pen.setColor(QtGui.QColor(19, 54, 255))
-	pen.setWidth(3) #3
-	paint.setPen(pen)
-	for p in range(0, records.Index-data.Derivation-Xscale, Xscale): #sleep pattern outline
-		i=p-GraphStart_index
-		x=i/Xscale+1
-		y0=data.Ysize-records.arrData[6][p]-5
-		y1=data.Ysize-records.arrData[6][p+Xscale]-5
-		paint.drawLine(x, y0, x+1, y1)
+        pen.setColor(QtGui.QColor(19, 54, 255))
+        pen.setWidth(3) #3
+        paint.setPen(pen)
+        for p in range(0, records.Index-data.Derivation-Xscale, Xscale): #sleep pattern outline
+            i=p-GraphStart_index
+            x=i/Xscale+1
+            y0=data.Ysize-records.arrData[6][p]-5
+            y1=data.Ysize-records.arrData[6][p+Xscale]-5
+            paint.drawLine(x, y0, x+1, y1)
 
         #Lucid dream option
         if(records.Use_Lucid_Dream_Song==True and records.Lucid_Dream_Song_Start_tuple!=-1):
@@ -397,6 +393,8 @@ def DrawGraph(self, QtGui):
             y=20
             paint.drawPolygon(QPointF(x00, y-6), QPointF(x00, y+6), QPointF(x00+6, y))
             paint.drawRect(x00, y-1, x01-x00, 2)
+#            paint.drawPolygon(QPointF(x00, y-5), QPointF(x01, y-5), QPointF(x01, y-8))
+
 
        #alarm visualisation
         if(records.AlarmIsSet==True): #alarm time window is set, show it
@@ -409,6 +407,7 @@ def DrawGraph(self, QtGui):
             paint.drawRect(x00, 8, x10-x00, 2) #Time Window
             paint.drawRect(x10, 4, 1, 10)  #Last Alarm opportunity
 
+            #alarm point
             if(data.AlarmIsActive==True or data.run==False): #only show alarm if alarm occured or in view mode
                 if(records.AlarmTime_seconds!=-1):
                     if(records.EndTime_seconds>=records.AlarmTime_seconds-60): #alarm got set off during recording (-60 is workaround)
@@ -434,7 +433,10 @@ def DrawGraph(self, QtGui):
                     t=data.Trigger
                 y=(data.Ysize-(t*data.Yscale_Sleep_Pattern*3/40))+10
                 paint.setPen(QtGui.QColor(255, 255, 255, 200))
-                paint.drawLine(1, y-17, data.GraphBitMapLen, y-17)  #Trigger line
+#                paint.drawLine(1, y-17, data.GraphBitMapLen, y-17)  #Trigger line
+                x0=Tuple2Index(records.AlarmTimeWindowStart_tuple)-data.Derivation*Xscale
+                x00=(x0-GraphStart_index)/Xscale
+                paint.drawLine(x00, y-17, data.GraphBitMapLen, y-17)  #Trigger line
                 if(y<18):
                     y=33
                     #draw arrow
@@ -475,8 +477,8 @@ def DrawGraph(self, QtGui):
 ###########################################################################
 ## Function:    MakeNoise_if_over_trigger
 ## Description: This function plays a wav file when ever the movement is
-##				over the trigger level.
-##				It is only used in quick mode measurement
+##                over the trigger level.
+##                It is only used in quick mode measurement
 ## Parameters:  current movement
 ## Returns:     none
 ###########################################################################
@@ -550,9 +552,9 @@ def DrawStatistic(self, QtGui, QtCore):
 ###########################################################################
 ## Function:    GenerateStatisticData
 ## Description: This function generates the statistics from the record
-##				data and puts it into the statistics array
-##				As this function also is time consuming, it is exported
-##				into a c function. See GenerateSleepPattern() for mre details
+##                data and puts it into the statistics array
+##                As this function also is time consuming, it is exported
+##                into a c function. See GenerateSleepPattern() for mre details
 ## Parameters:  none
 ## Returns:     none
 ###########################################################################
@@ -575,7 +577,7 @@ def GenerateStatisticData():
 ###########################################################################
 ## Function:    InitRecord
 ## Description: This function clears all data in the record and initialises
-##				it for the measurement
+##                it for the measurement
 ## Parameters:  none
 ## Returns:     none
 ###########################################################################
@@ -631,7 +633,7 @@ def InitRecord():
 ###########################################################################
 ## Function:    PrintRecordData
 ## Description: This function prints out all data in the record.
-##				It is only used for debugging
+##                It is only used for debugging
 ## Parameters:  ShowArray: True/False
 ## Returns:     none
 ###########################################################################
